==> gpsjinni_0.9.20101005-1.tar.gz: gpsjinni-0.9.20101005/src/Compass.h <==
#ifndef COMPASS_H
#define COMPASS_H

/*
  GPSJinni - show raw data from the GPS subsystem.
  Copyright (C) 2009  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Object.h>

#include <Lum/Model/Number.h>
#include <Lum/Model/Boolean.h>

class Compass : public Lum::Control
{
private:
  Lum::OS::ColorRef     arrowColorRight;
  Lum::OS::ColorRef     arrowColorLeft;
  Lum::OS::ColorRef     arrowShadowColor;
  Lum::Model::DoubleRef model;
  Lum::Model::BooleanRef arrowShowCourseDirection;	// north direction otherwise.
  Lum::Model::ActionRef refreshTimer;
  double                lastDirection;

public:
  Compass();

  bool SetModel(Lum::Base::Model* model);
  void SetShowCourseDirection(Lum::Model::Boolean *arrowShowCourse);

  void CalcSize();
  void Draw(Lum::OS::DrawInfo* draw,
            int x, int, size_t w, size_t h);

  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);

  static Compass* Create(Lum::Base::Model* model,
                         bool horizontalFlex=false,
                         bool verticalFlex=false,
                         Lum::Model::Boolean* arrowShowCourse=NULL);
};

#endif

==> gpsjinni_0.9.20101221-5.tar.gz: gpsjinni-0.9.20101221/src/Compass.h <==
#ifndef COMPASS_H
#define COMPASS_H

/*
  GPSJinni - show raw data from the GPS subsystem.
  Copyright (C) 2009  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Object.h>

#include <Lum/Model/Number.h>
#include <Lum/Model/Boolean.h>

class Compass : public Lum::Control
{
private:
  Lum::OS::ColorRef      arrowColorRight;
  Lum::OS::ColorRef      arrowColorLeft;
  Lum::OS::ColorRef      arrowShadowColor;
  Lum::Model::NumberRef  model;
  Lum::Model::BooleanRef arrowShowCourseDirection; //! north direction otherwise.
  Lum::Model::ActionRef  refreshTimer;
  double                 lastDirection;

public:
  Compass();

  bool SetModel(Lum::Base::Model* model);
  void SetShowCourseDirection(Lum::Model::Boolean *arrowShowCourse);

  void CalcSize();
  void Draw(Lum::OS::DrawInfo* draw,
            int x, int, size_t w, size_t h);

  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);

  static Compass* Create(Lum::Base::Model* model,
                         bool horizontalFlex=false,
                         bool verticalFlex=false,
                         Lum::Model::Boolean* arrowShowCourse=NULL);
};

#endif
